from django import template
from django.utils.safestring import mark_safe
from django.urls import reverse_lazy
from django.template.defaultfilters import pluralize
from django.db.models import OuterRef, Subquery


from agenda_culturel.models import RecurrentImport, BatchImportation

from .utils_extra import picto_from_name

register = template.Library()


@register.simple_tag
def show_badge_rimports(placement, status):
    newest = BatchImportation.objects.filter(recurrentImport=OuterRef("pk")).order_by(
        "-created_date"
    )
    nb = (
        RecurrentImport.objects.annotate(
            last_run_status=Subquery(newest.values("status")[:1])
        )
        .filter(last_run_status=status)
        .count()
    )

    if status == BatchImportation.STATUS.FAILED:
        suffix = 'en erreur'
        picto = "alert-triangle"
        cl    = "error"
    else:
        suffix = ' en cours'
        picto = "refresh-cw"
        cl    = "simple"

    if nb != 0:
        return mark_safe(
            '<a href="'
            + reverse_lazy("recurrent_imports_status", args=[status])
            + '" class="badge ' + cl + '" data-placement="'
            + placement
            + '" data-tooltip="'
            + str(nb)
            + " importation"
            + pluralize(nb)
            + " récurrente"
            + pluralize(nb)
            + ' ' + suffix + '">'
            + picto_from_name(picto)
            + " "
            + str(nb)
            + "</a>"
        )
    else:
        return ""
